@@ -3,7 +3,12 @@
 
 __author__ = 'Thomas Sterren'
 __contributors__ = []
-__version__ = '1.0.1'
+__version__ = '1.1.0'
+
+
+def main():
+    print(__version__)
+
 
 if __name__ == '__main__':
-    print(__version__)
+    main()
